==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/bd/vbd700.cpp <==
/****************************************************************************

  module      : vbd700.cpp

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: eventing
  description : description ...


  last changed: 1999-07-26  10:39
                2000-03-01  PTS 1104573 Alexander Kley 1/3/2000 
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/

// CRS 1103110 Alexander Kley 20/07/99

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gbd700.h"
#include "hgg01.h"

#if COMPILEMODE_MEO00 >= SLOW_MEO00
#include "hta99.h"
#endif
 
/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE  inline
#endif

#define DUMMY_NUMBER 0

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/

static cbd700_EventSet  bd700DBFillingEventSet  (sp31ei_db_filling_above_limit, 
												 sp31ei_db_filling_below_limit,
												 sp31ei_db_filling_changed); 
static cbd700_EventSet  bd700OMSDataHitRate     (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_oms_hitrate);
static cbd700_EventSet  bd700OMSLogHitRate      (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_omslog_hitrate);
static cbd700_EventSet  bd700LogHitRate         (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_log_hitrate);

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/

externPascal pasbool     bd10control_db_filling;
externPascal pasbool     bd20control_hit_rates;
externPascal tsp00_Int2  bd20refresh_hit_rate; 
//externPascal pasbool     k56control_log_full_events;
//externPascal pasbool     k56control_objlog_min_free;

/*===========================================================================*
 *  LOCAL VARIABLES                                                       *
 *===========================================================================*/

/*
PTS 1104573 Alexander Kley 1/3/2000
bool bd700_ObserveLogHitRate;
bool bd700_ObserveOMSDataHitRate;
bool bd700_ObserveOMSLogHitRate;
*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/

inline void
bd700_GetEvent (const tsp31_event_prio_Param   EventPriority,
				tsp31_short_event_desc        &ShortEventDesc);

/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

externC void
bd700AddEvent (
			   tsp31_event_ident_Param   EventId,
			   tsp00_Int4                EventThreshold,
			   tsp31_event_prio_Param    EventPrio
			   )
{
	ROUTINE_DBG_MSP00 ("bd700AddEvent");
	
	switch (EventId)
	{
    /* the following events cannot be set by an user anymore
	   PTS 1104573 Alexander Kley 1/3/2000
	case sp31ei_datacache_log_hitrate:
		bd700_ObserveLogHitRate = bd700LogHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio); 
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_oms_hitrate:
		bd700_ObserveOMSDataHitRate = bd700OMSDataHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio);
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_omslog_hitrate:
        bd700_ObserveOMSLogHitRate = bd700OMSLogHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio);
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
    */
	case sp31ei_db_filling_above_limit:
		bd10control_db_filling = bd700DBFillingEventSet.bd700AddEvent (EventThreshold, OVERFLOW_BD700,  EventPrio); break;
	case sp31ei_db_filling_below_limit:
		bd10control_db_filling = bd700DBFillingEventSet.bd700AddEvent (EventThreshold, UNDERFLOW_BD700, EventPrio); break;
	default:
		break;
	}
}

/*---------------------------------------------------------------------------*/

externC void
bd700DelEvent (
			   tsp31_event_ident_Param  EventId,
			   tsp00_Int4               EventThreshold
			   )
{
	ROUTINE_DBG_MSP00 ("bd700DelEvent");
	
	switch (EventId)
	{
    /* the following events cannot be set by an user anymore
	   PTS 1104573 Alexander Kley 1/3/2000
	case sp31ei_datacache_log_hitrate:
		bd700_ObserveLogHitRate = bd700LogHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700); 
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;		
		break;
	case sp31ei_datacache_oms_hitrate:
		bd700_ObserveOMSDataHitRate = bd700OMSDataHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700);
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_omslog_hitrate:
        bd700_ObserveOMSLogHitRate = bd700OMSLogHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700); 
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ControlOMSLogHitRate;
		break;
    */
	case sp31ei_db_filling_above_limit:
		bd10control_db_filling = bd700DBFillingEventSet.bd700DelEvent (EventThreshold, OVERFLOW_BD700);  break;
	case sp31ei_db_filling_below_limit:
		bd10control_db_filling = bd700DBFillingEventSet.bd700DelEvent (EventThreshold, UNDERFLOW_BD700); break;
	default:
		break;
	}
}

/*---------------------------------------------------------------------------*/

externC void
bd700ControlEvent (
				   tsp31_event_ident_Param  EventId,
				   tsp00_Int4               Value
				   )
{
	ROUTINE_DBG_MSP00 ("bd700ControlEvent");
	
	switch (EventId)
	{
	case sp31ei_datacache_oms_hitrate:
		bd700OMSDataHitRate.bd700Control (Value);     break;
	case sp31ei_datacache_log_hitrate:
		bd700LogHitRate.bd700Control (Value);         break;
	case sp31ei_datacache_omslog_hitrate:
        bd700OMSLogHitRate.bd700Control (Value);      break;
	case sp31ei_db_filling_above_limit:
	case sp31ei_db_filling_below_limit:
		bd700DBFillingEventSet.bd700Control (Value);  break;
	default:
		break;
	}
}

/*---------------------------------------------------------------------------*/

externC void
bd700GetEvents (tsp31_short_event_desc & ShortEventDesc)
{ 
	ROUTINE_DBG_MSP00 ("bd700GetEvents");
	
	tsp31_event_ident &EventId = ShortEventDesc.sp31sed_ident;
	
	switch (EventId)
	{
    /* the following events cannot be set by an user anymore
	   PTS 1104573 Alexander Kley 1/3/2000
	case sp31ei_datacache_log_hitrate:
		bd700LogHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);        break;
	case sp31ei_datacache_oms_hitrate:
		bd700OMSDataHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);    break;
	case sp31ei_datacache_omslog_hitrate:
        bd700OMSLogHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);     break;
    */
	case sp31ei_db_filling_above_limit:
		bd700DBFillingEventSet.bd700GetEvents (ShortEventDesc, OVERFLOW_BD700);  break;
	case sp31ei_db_filling_below_limit:
		bd700DBFillingEventSet.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700); break;
	default:
		break;
	}
}

/*---------------------------------------------------------------------------*/

externC void
bd700SetSystemDefinedEvents()
{
	ROUTINE_DBG_MSP00 ("bd700SetSystemDefinedEvents");
	
	//-------------------
	// DataBase occupancy
	//-------------------
	bd10control_db_filling = true;
	
	// define a number of data cache filling levels on a grid. Whenever 
	// the actual value passes one of these values an event is sent
	const int MinDBFilling        =     0;
	const int MaxDBFilling        = 10000;  // in units of  0.01 %
	const int NumDBFillingsOnGrid =    50;
	bd700DBFillingEventSet.bd700SetGridEvent  (MinDBFilling,
		MaxDBFilling, NumDBFillingsOnGrid, sp31ep_low);

	// add additional events which display dangerous situations	
	bd700DBFillingEventSet.bd700AddEvent (9000, OVERFLOW_BD700,  sp31ep_medium);
	bd700DBFillingEventSet.bd700AddEvent (9500, OVERFLOW_BD700,  sp31ep_high);
	bd700DBFillingEventSet.bd700AddEvent (9600, OVERFLOW_BD700,  sp31ep_high);
	bd700DBFillingEventSet.bd700AddEvent (9700, OVERFLOW_BD700,  sp31ep_high);
	bd700DBFillingEventSet.bd700AddEvent (9800, OVERFLOW_BD700,  sp31ep_high);
	bd700DBFillingEventSet.bd700AddEvent (9900, OVERFLOW_BD700,  sp31ep_high);
	
	//--------------------
	// DataCache hit rates
	//--------------------

	bd20control_hit_rates  = true;
	bd20refresh_hit_rate   = 0;
	
	// define a number of loghitrates on a grid. Whenever the actual 
	// loghitratepasses passes one of these values an event is sent
	const int MinLogHitRate        =     0;
	const int MaxLogHitRate        = 10000; // in units of  0.01 %
	const int NumLogHitRatesOnGrid =    20;
	bd700LogHitRate.bd700SetGridEvent  (MinLogHitRate,
		MaxLogHitRate, NumLogHitRatesOnGrid, sp31ep_low);
	
	if (g01is_livecache())
	{
		// define a number of OMSDataCacheHitRates on a grid. Whenever the actual 
		// OMSDataCacheHitRates passes one of these values an event is sent
		const int MinOMSDataHitRate        =     0;
		const int MaxOMSDataHitRate        = 10000; // in units of  0.01 %
		const int NumOMSDataHitRatesOnGrid =   100;
		bd700OMSDataHitRate.bd700SetGridEvent  (MinOMSDataHitRate,
			MaxOMSDataHitRate,NumOMSDataHitRatesOnGrid, sp31ep_low);
		
		// define a number of OMSDataCacheHitRates on a grid. Whenever the actual 
		// OMSDataCacheHitRates passes one of these values an event is sent
		const int MinOMSLogHitRate        =     0;
		const int MaxOMSLogHitRate        = 10000; // in units of  0.01 %
		const int NumOMSLogHitRatesOnGrid =    20;
		bd700OMSLogHitRate.bd700SetGridEvent  (MinOMSLogHitRate,
			MaxOMSLogHitRate,NumOMSLogHitRatesOnGrid, sp31ep_low);
	}
}

/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/

inline void
bd700_GetEvent (const tsp31_event_prio_Param   EventPriority,
				tsp31_short_event_desc        &ShortEventDesc)
{
	ShortEventDesc.sp31sed_eventarr[0].sp31oei_priority.becomes(EventPriority);
	
	if (sp31ep_nil != EventPriority)
		ShortEventDesc.sp31sed_eventcnt = 1;
	else
		ShortEventDesc.sp31sed_eventcnt = 0;
}

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/bd/vbd700.cpp <==
/****************************************************************************

  module      : vbd700.cpp

  -------------------------------------------------------------------------

  responsible : AlexanderK

  special area: eventing
  description : description ...


  last changed: 1999-07-26  10:39
                2000-03-01  PTS 1104573 Alexander Kley 1/3/2000 
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin  GPL
    Copyright (C) 2000 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end

*****************************************************************************/

// CRS 1103110 Alexander Kley 20/07/99

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gbd700.h"
#include "hgg01.h"

#if COMPILEMODE_MEO00 >= SLOW_MEO00
#include "hta99.h"
#endif
 
/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE  inline
#endif

#define DUMMY_NUMBER 0

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/

/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/
/*
static cbd700_EventSet  bd700DBFillingEventSet  (sp31ei_db_filling_above_limit, 
												 sp31ei_db_filling_below_limit,
												 sp31ei_db_filling_changed); 
*/
static cbd700_EventSet  bd700OMSDataHitRate     (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_oms_hitrate);
static cbd700_EventSet  bd700OMSLogHitRate      (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_omslog_hitrate);
static cbd700_EventSet  bd700LogHitRate         (sp31ei_nil,
												 sp31ei_nil,
												 sp31ei_datacache_log_hitrate);

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/

//externPascal pasbool     bd10control_db_filling;
externPascal pasbool     bd20control_hit_rates;
externPascal tsp00_Int2  bd20refresh_hit_rate; 
//externPascal pasbool     k56control_log_full_events;
//externPascal pasbool     k56control_objlog_min_free;

/*===========================================================================*
 *  LOCAL VARIABLES                                                       *
 *===========================================================================*/

/*
PTS 1104573 Alexander Kley 1/3/2000
bool bd700_ObserveLogHitRate;
bool bd700_ObserveOMSDataHitRate;
bool bd700_ObserveOMSLogHitRate;
*/

/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/

inline void
bd700_GetEvent (const tsp31_event_prio_Param   EventPriority,
				tsp31_short_event_desc        &ShortEventDesc);

/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/
/*
externC void
bd700AddEvent (
			   tsp31_event_ident_Param   EventId,
			   tsp00_Int4                EventThreshold,
			   tsp31_event_prio_Param    EventPrio
			   )
{
	ROUTINE_DBG_MSP00 ("bd700AddEvent");
	
	switch (EventId)
	{
	case sp31ei_datacache_log_hitrate:
		bd700_ObserveLogHitRate = bd700LogHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio); 
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_oms_hitrate:
		bd700_ObserveOMSDataHitRate = bd700OMSDataHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio);
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_omslog_hitrate:
        bd700_ObserveOMSLogHitRate = bd700OMSLogHitRate.bd700AddEvent (EventThreshold, UNDERFLOW_BD700,  EventPrio);
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
  	default:
		break;
	}
}
*/
/*---------------------------------------------------------------------------*/
/*
externC void
bd700DelEvent (
			   tsp31_event_ident_Param  EventId,
			   tsp00_Int4               EventThreshold
			   )
{
	ROUTINE_DBG_MSP00 ("bd700DelEvent");
	
	switch (EventId)
	{
    // the following events cannot be set by an user anymore
	   PTS 1104573 Alexander Kley 1/3/2000
	case sp31ei_datacache_log_hitrate:
		bd700_ObserveLogHitRate = bd700LogHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700); 
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;		
		break;
	case sp31ei_datacache_oms_hitrate:
		bd700_ObserveOMSDataHitRate = bd700OMSDataHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700);
		bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ObserveOMSLogHitRate;
		break;
	case sp31ei_datacache_omslog_hitrate:
        bd700_ObserveOMSLogHitRate = bd700OMSLogHitRate.bd700DelEvent (EventThreshold, UNDERFLOW_BD700); 
        bd20control_hit_rates = bd700_ObserveLogHitRate || bd700_ObserveOMSDataHitRate || bd700_ControlOMSLogHitRate;
		break;
		break;
	}
}
*/
/*---------------------------------------------------------------------------*/

externC void
bd700ControlEvent (
				   tsp31_event_ident_Param  EventId,
				   tsp00_Int4               Value
				   )
{
	ROUTINE_DBG_MSP00 ("bd700ControlEvent");
	
	switch (EventId)
	{
	case sp31ei_datacache_oms_hitrate:
		bd700OMSDataHitRate.bd700Control (Value);     break;
	case sp31ei_datacache_log_hitrate:
		bd700LogHitRate.bd700Control (Value);         break;
	case sp31ei_datacache_omslog_hitrate:
        bd700OMSLogHitRate.bd700Control (Value);      break;
    /*
	case sp31ei_db_filling_above_limit:
	case sp31ei_db_filling_below_limit:
		bd700DBFillingEventSet.bd700Control (Value);  break;
    */
	default:
		break;
	}
}

/*---------------------------------------------------------------------------*/
/*
externC void
bd700GetEvents (tsp31_short_event_desc & ShortEventDesc)
{ 
	ROUTINE_DBG_MSP00 ("bd700GetEvents");
	
	tsp31_event_ident &EventId = ShortEventDesc.sp31sed_ident;
	
	switch (EventId)
	{
	case sp31ei_datacache_log_hitrate:
		bd700LogHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);        break;
	case sp31ei_datacache_oms_hitrate:
		bd700OMSDataHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);    break;
	case sp31ei_datacache_omslog_hitrate:
        bd700OMSLogHitRate.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700);     break;
	case sp31ei_db_filling_above_limit:
		bd700DBFillingEventSet.bd700GetEvents (ShortEventDesc, OVERFLOW_BD700);  break;
	case sp31ei_db_filling_below_limit:
		bd700DBFillingEventSet.bd700GetEvents (ShortEventDesc, UNDERFLOW_BD700); break;
	default:
		break;
	}
}
*/
/*---------------------------------------------------------------------------*/

externC void
bd700SetSystemDefinedEvents()
{
	ROUTINE_DBG_MSP00 ("bd700SetSystemDefinedEvents");
	
	//--------------------
	// DataCache hit rates
	//--------------------

	bd20control_hit_rates  = true;
	bd20refresh_hit_rate   = 0;
	
	// define a number of loghitrates on a grid. Whenever the actual 
	// loghitratepasses passes one of these values an event is sent
	const int MinLogHitRate        =     0;
	const int MaxLogHitRate        = 10000; // in units of  0.01 %
	const int NumLogHitRatesOnGrid =    20;
	bd700LogHitRate.bd700SetGridEvent  (MinLogHitRate,
		MaxLogHitRate, NumLogHitRatesOnGrid, sp31ep_low);
	
	if (g01is_livecache())
	{
		// define a number of OMSDataCacheHitRates on a grid. Whenever the actual 
		// OMSDataCacheHitRates passes one of these values an event is sent
		const int MinOMSDataHitRate        =     0;
		const int MaxOMSDataHitRate        = 10000; // in units of  0.01 %
		const int NumOMSDataHitRatesOnGrid =   100;
		bd700OMSDataHitRate.bd700SetGridEvent  (MinOMSDataHitRate,
			MaxOMSDataHitRate,NumOMSDataHitRatesOnGrid, sp31ep_low);
		
		// define a number of OMSDataCacheHitRates on a grid. Whenever the actual 
		// OMSDataCacheHitRates passes one of these values an event is sent
		const int MinOMSLogHitRate        =     0;
		const int MaxOMSLogHitRate        = 10000; // in units of  0.01 %
		const int NumOMSLogHitRatesOnGrid =    20;
		bd700OMSLogHitRate.bd700SetGridEvent  (MinOMSLogHitRate,
			MaxOMSLogHitRate,NumOMSLogHitRatesOnGrid, sp31ep_low);
	}
}

/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/

inline void
bd700_GetEvent (const tsp31_event_prio_Param   EventPriority,
				tsp31_short_event_desc        &ShortEventDesc)
{
	ShortEventDesc.sp31sed_eventarr[0].sp31oei_priority.becomes(EventPriority);
	
	if (sp31ep_nil != EventPriority)
		ShortEventDesc.sp31sed_eventcnt = 1;
	else
		ShortEventDesc.sp31sed_eventcnt = 0;
}

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
